/*	
    main.cpp
    Sets up a brain-dead example of how to use the BLinearPlot library
    Copyright (c) 1996 by Erik Rubin
    All Rights Reserved
*/

#ifndef PLOTTESTWINDOW_H
#include "PlotTestWindow.h"
#endif
#ifndef BLINEARPLOT_H
#include "BLinearPlotShip.h"
#endif
#ifndef APPSETUP_H
#include "AppSetup.h"
#endif

main()
{	
	TestBLinearPlotApp *TestApplication;

	TestApplication = new TestBLinearPlotApp();
	TestApplication->Run();
	
	delete(TestApplication);
	return(0);
}

TestBLinearPlotApp::TestBLinearPlotApp()
		  		  : BApplication('HLWD')
{
	PlotTestWindow  *   TestWindow;
	BLinearPlot		*   LinearPlot;
	BRect			    WinRect;
	float               SomePlotData1[MAXPOINTS];
	float               SomePlotData2[MAXPOINTS];
	float               SomePlotData3[MAXPOINTS];
	float               SomePlotData4[MAXPOINTS];
	float               SomePlotData5[MAXPOINTS];
    int                 i;

	WinRect.Set(40, 40, 520, 380);
	TestWindow = new PlotTestWindow(WinRect);


	/* ---------
	   build/initialize PlotBox
       --------- */

    BRect   PlotRect;
    BBox  * PlotBox;
    PlotRect = TestWindow->Bounds();
    PlotRect.top = PlotRect.top + 20;
    PlotRect.left = PlotRect.left + 20;
    PlotRect.right = PlotRect.right - 20;
    PlotRect.bottom = PlotRect.bottom - 20;

	PlotBox = new BBox(PlotRect,
					  "PlotBox",
					  B_FOLLOW_LEFT | B_FOLLOW_TOP,
					  B_WILL_DRAW);	

    TestWindow->Lock();
    PlotBox->SetLowColor(216,216,216);
    PlotBox->SetViewColor(216,216,216);
    PlotBox->SetLabel("Plot View");
    PlotBox->Invalidate();
    TestWindow->Unlock();   
	TestWindow->AddChild(PlotBox);
    PlotBox->AttachedToWindow();


    /* ---------
       Use the PlotRect to specify an 
       area within the PlotBox 
       ---------*/
	PlotRect.Set(15,15,430,290);	


    /* Get an instance of BLinearPlot */
	LinearPlot = new BLinearPlot(PlotRect, "BLinearPlot", "Test X", "  Test Y");
	
	/* Put the plot inside the PlotBox */
	PlotBox->AddChild(LinearPlot);


    /* ---- 
       Create the fake data
       ---- */

    for (i = 0; i < MAXPOINTS; i++)
    {
      SomePlotData1[i] = (i);
      SomePlotData2[i] = 2.2 * (i) + 2;
      SomePlotData3[i] = 5.2 * (i);
      SomePlotData4[i] = 4 * (i);
      SomePlotData5[i] = 3.3 * (i);
    }    
    SomePlotData1[13] = 100;
    SomePlotData2[14] = 111;
    SomePlotData3[23] = 106;
    SomePlotData4[11] = 100;
    SomePlotData5[16] = 60;

	
	/* make window visible */
	TestWindow->Show();

    #define SET_ONE      1
    #define SET_TWO      2
    #define SET_THREE    3
    #define SET_FOUR     4
    #define SET_FIVE     5
    rgb_color BackColor;
    rgb_color Plot1Color;
    rgb_color Plot2Color;
    rgb_color Plot3Color;
    rgb_color Plot4Color;
    rgb_color Plot5Color;

    /* Set up some colors */
    BackColor.red = 60;
    BackColor.green = 170;
    BackColor.blue = 200;

    Plot1Color.red = 200;
    Plot1Color.green = 200;
    Plot1Color.blue = 200;

    Plot2Color.red = 250;
    Plot2Color.green = 30;
    Plot2Color.blue = 20;

    Plot3Color.red = 2;
    Plot3Color.green = 2;
    Plot3Color.blue = 2;

    Plot4Color.red = 255;
    Plot4Color.green = 255;
    Plot4Color.blue = 255;

    Plot5Color.red = 20;
    Plot5Color.green = 250;
    Plot5Color.blue = 20;

    TestWindow->Lock();

    /* Tell LinearPlot to set some colors */
    LinearPlot->SetBackColor(BackColor);
    LinearPlot->SetPlotColor(SET_ONE, Plot1Color);
    LinearPlot->SetPlotColor(SET_TWO, Plot2Color);
    LinearPlot->SetPlotColor(SET_THREE, Plot3Color);
    LinearPlot->SetPlotColor(SET_FOUR, Plot4Color);
    LinearPlot->SetPlotColor(SET_FIVE, Plot5Color);

    /* Tell LinearPlot to connect dots for some sets */
    LinearPlot->ConnectDots(SET_ONE, true);
    LinearPlot->ConnectDots(SET_THREE, true);

    /* Tell LinearPlot to do XTicks and YTicks for intervals of 10 and 25 */
    LinearPlot->XTicks(true, 10);
    LinearPlot->YTicks(true, 25);

    /* Tell LinearPlot to put numbers at ticks at certain intervals */
    LinearPlot->XAxis_TickNumbers(true, 10);
    LinearPlot->YAxis_TickNumbers(true, 25);


    /* Tell LinearPlot NOT to draw numbers at the end of the axes.  This
       looks nicer when we're using XTickNumbers.  When we don't use
       XTickNumbers, it looks nicer to have these turned on.
    */
    LinearPlot->ShouldDrawFinalXLabel(false);
    LinearPlot->ShouldDrawFinalYLabel(false);


    /* ---- 
       test: tell the graph to plot the 
       first 32 points of the data sets
       ---- */
    LinearPlot->ReceiveDataSet(SomePlotData1, SET_ONE, 32, false);
    LinearPlot->ReceiveDataSet(SomePlotData2, SET_TWO, 32, false);
    LinearPlot->ReceiveDataSet(SomePlotData3, SET_THREE, 32, false);
    LinearPlot->ReceiveDataSet(SomePlotData4, SET_FOUR, 32, false);
    LinearPlot->ReceiveDataSet(SomePlotData5, SET_FIVE, 32, true);   // hold off drawing until last value is sent

    TestWindow->Unlock();

}
